
NIP-52
======

Badges
------

`draft` `optional` `author:neilck`

*This NIP is currently in draft, and review / comments are sought.* 

This NIP enables an app owner (or community manager) to award badges to their members. 

## Kind XX: Issue Badge

EVENT sent from client to relay to issue a badge.

```json
{
  "id": <32-bytes lowercase hex-encoded sha256 of the the serialized event data>,
  "pubkey": <32-bytes lowercase hex-encoded public key of the app owner issuing the badge>,
  "created_at": <unix timestamp in seconds> ,
  "kind": XX,
  "tags": [
    ["p", <32-bytes hex pubkey of the member receiving the badge> ],
    ["badge_type", <string specifying badge type> ]
  ],
  "content": <stringified json object containing badge content>,
  "sig": <64-bytes signature of the sha256 hash of the serialized event data, which is the same as the "id" field>
}
```

`p tag` MUST contain exactly one entry, the pubkey of the claim's subject.

`badge_type` is used as a reference field to calcuate badge image url.

Like Kind 0, badges provide metadata about a pubkey, but the event is sent (and thus signed) by the app owner, not the subject's pubkey.

### Badge Content Schema

```json
{
    "name": <string of badge name to display>,
    "message": <string of message>,
    "expiry_date": <optional integer of unix timestamp in secs when badge expires>,
    <additional key/value pairs>
}
````

Examples as stringified JSON object in content

Badge for an achievement
```json
{
  ...
  "content": "{\"name\": \"Donation\", \"message\": \"User has sent a sats donation to noster.directory.\"}",
  ...
}
````

Badge for a membership
```json
{
  ...
  "content": "{\"name\": \"My App Premium Supporter\", \"message\": \"User is a premium supporter of My App.\", \"expiry_date\": 1674818142}",
  ...
}
````

- name - name of the badge. e.g. "Donation", "Top Bug Crusher"
- message - Text description for the badge
- expiry_date - Optional - Intended use is for when a badge is associated with additional client or relay permissions that expire. For example, issuing a badge for paid subscribers that removes rate limits for their pubkey.

Client may include additional key/value pairs in content.

See <link TBD> for an example of fields for linking other social media accounts to a Nostr pubkey using badges.

### Using `badge_type` to get badge image

To support images for their badges, an app owner first sets a NIP-52 template url in their Kind 0: content (similar to how NIP-05 works).

```json
{
  "pubkey": "b0635d6a9851d3aed0cd6c495b282167acf761729078d975fc341b22650b07b9",
  "kind": 0,
  "content": "{\"name\": \"My App\", \"nip52\": \"https://myapp.com/[badge_type].svg\"}"
  ...
}
````

Clients SHOULD replace the `[badge_type]` place holder in the template URL with the `badge_type` value from the event, to calcuate the badge image url.

The `[badge_type]` place holder can be in the URL path, part of a file name, as a query parameter, or omitted all together if an app owner wants to the use the same images for all badges.

It is recommended that badge images have a square aspect ratio for display compatibility between clients. 


Motivation
----------

Badges allow a user to be recognized for their contributions within an app /  community. With badges stored as events in Nostr against pubkeys, users can bring their reputation with them as they switch between apps, something they can't do with current social media apps.
